@@ -22,5 +22,5 @@ Global settings and variables re-used across the project
 
 XFILE_DEST = "ComposeXFile"
 DIR_DEST = "OutputDirectory"
-FILE_DEST = "OutputFile"
 CFN_EXPORT_DELIMITER = r"::"
+X_KEY = r"x-"
