@@ -46,10 +46,8 @@ def render_codepipeline_config_file(parameters):
     """
     if not parameters:
         return
-    config = {
-        "Parameters": {},
-        "Tags": {}
-    }
+    config = {"Parameters": {}, "Tags": {}}
+
     for param in parameters:
         config["Parameters"].update({param["ParameterKey"]: param["ParameterValue"]})
     return config
@@ -155,7 +153,6 @@ class ComposeXStack(Stack, object):
             config_file.upload(settings)
             LOG.debug(f"Rendered URL = {file.url}")
 
-
     def render_parameters_list_cfn(self):
         """
         Renders parameters in a CFN parameters config file format
