@@ -31,7 +31,11 @@ from ecs_composex.common.cfn_params import (
     ROOT_STACK_NAME_T,
     ROOT_STACK_NAME,
 )
-from ecs_composex.dns import dns_params, dns_conditions
+from ecs_composex.dns import dns_params
+from ecs_composex.dns.dns_conditions import (
+    CREATE_PUBLIC_NAMESPACE_CON_T,
+    CREATE_PUBLIC_NAMESPACE_CON,
+)
 from ecs_composex.ecs import ecs_conditions, ecs_params
 from ecs_composex.ecs.ecs_params import (
     CLUSTER_NAME,
@@ -44,10 +48,6 @@ from ecs_composex.ecs.ecs_service import (
 )
 from ecs_composex.ecs.ecs_service_config import ServiceConfig
 from ecs_composex.vpc import vpc_params
-from ecs_composex.dns.dns_conditions import (
-    CREATE_PUBLIC_NAMESPACE_CON_T,
-    CREATE_PUBLIC_NAMESPACE_CON,
-)
 
 
 def initialize_service_template(service_name):
